# dansink.mk:dans共通インクルードファイル Version 7.42  Copyleft (c) 杉本典夫
# Time-stamp: <2024-11-02 08:45:42 tac>
#
# 使用法:各Makefileにインクルードして使用する
# 各Makefileではnameとcomsを指定する。
#        make         … 実行ファイルを作成する
#        make arcs    … 圧縮アーカイブファイルを作成する
#        make install … 実行ファイルとドキュメントファイルをインストールする
#        make debs    … デバッグ用実行ファイルを作成する
#        make clean   … 不要なファイルを削除する
#
# CXXは環境変数で設定する方法もあるが、ここではMakefile中で設定している。

outs = $(addsuffix .out,$(coms))
debs = $(outs:.out=.db)
sous = $(outs:.out=.C)
mans = $(outs:.out=.1)
bshs = $(outs:.out=.bsh)
txts = $(outs:.out=_*_v*.txt)
dats = $(outs:.out=_*_v*.dat)
tabs = $(outs:.out=_*_v*.tab)
dnss = $(outs:.out=_*_v*.d)

arcs = $(name).zip
addfiles = Makefile *_[0-9][0-9].dns *_[0-9][0-9].tab *.txt *.dat *.d

HEADS := $(LINCDIR)/fun.H $(LINCDIR)/mat.H $(LINCDIR)/dans.H

CXX := g++
CXXFLAGS := -O -s -W -I$(LINCDIR)
DEBFLAGS := -g -W -I$(LINCDIR)
LDFLAGS := -L$(LLIBDIR) -ldans -lfun

ARCOM := zip
ARCOMFLAGS := -u

all : $(outs)

arcs : $(arcs)

debs : $(debs)

$(outs) : $(HEADS)
# パターンルールを使用する

$(debs) : $(HEADS)
# パターンルールを使用する

$(arcs) : $(sous) $(mans) $(bshs) $(addfiles)
	$(ARCOM) $(ARCOMFLAGS) $@ $?

%.out : %.C
	$(CXX) $(CXXFLAGS) -o $@ $< $(LDFLAGS)

%.db : %.C
	$(CXX) $(DEBFLAGS) -o $@ $< $(LDFLAGS)

install : installout installman

installout : $(outs)
	for file in $? ; do cp -f -p $$file $(LBINDIR)/$${file%.out} ; done

installman : $(mans)
	for file in $? ; do cp -f -p $(PWD)/$$file $(LMANDIR) ; done

clean :
	rm -f $(debs) $(txts) $(dats) $(tabs) $(dnss) *.bak
